pub enum TaskLock {
None,
Force,
Lock(String),
Unlock(String),
}Variants
None
No lock. Fail the operation if the subject is locked.
Force
Force operation if the subject is locked.
Lock(String)
Use or apply a lock. Fail the operation if the subject is locked with a different lock.
Unlock(String)
Use and unlock after the operation. Fail the operation if the subject is locked with a different lock.